==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fUnknown.h <==
// class soot.coffi.Instruction_Unknown

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 55b4598613d1440f soot_coffi_Instruction__5fUnknown
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fUnknown_H_
#define _JC_soot_coffi_Instruction__5fUnknown_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fUnknown$sub_refs	_jc_soot_coffi_Instruction__5fUnknown$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs	_jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$refs	_jc_soot_coffi_Instruction__5fUnknown$refs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$nonrefs	_jc_soot_coffi_Instruction__5fUnknown$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$object	_jc_soot_coffi_Instruction__5fUnknown$object;

typedef const struct _jc_soot_coffi_Instruction__5fUnknown$vmethods	_jc_soot_coffi_Instruction__5fUnknown$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fUnknown$vtable	_jc_soot_coffi_Instruction__5fUnknown$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fUnknown$vtype	_jc_soot_coffi_Instruction__5fUnknown$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fUnknown$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fUnknown$object *, jbyte);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fUnknown$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fUnknown$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fUnknown$vmethods	soot_coffi_Instruction__5fUnknown;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fUnknown$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fUnknown$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fUnknown$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fUnknown$refs {
    _jc_soot_coffi_Instruction__5fUnknown$sub_refs	soot_coffi_Instruction__5fUnknown;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fUnknown$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs	soot_coffi_Instruction__5fUnknown;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fUnknown$object {
	_jc_soot_coffi_Instruction__5fUnknown$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fUnknown$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fUnknown$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fUnknown$vtype _jc_soot_coffi_Instruction__5fUnknown$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fUnknown, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fUnknown$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fUnknown_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fUnknown.h <==
// class soot.coffi.Instruction_Unknown

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 55b4598613d1440f soot_coffi_Instruction__5fUnknown
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fUnknown_H_
#define _JC_soot_coffi_Instruction__5fUnknown_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fUnknown$sub_refs	_jc_soot_coffi_Instruction__5fUnknown$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs	_jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$refs	_jc_soot_coffi_Instruction__5fUnknown$refs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$nonrefs	_jc_soot_coffi_Instruction__5fUnknown$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fUnknown$object	_jc_soot_coffi_Instruction__5fUnknown$object;

typedef const struct _jc_soot_coffi_Instruction__5fUnknown$vmethods	_jc_soot_coffi_Instruction__5fUnknown$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fUnknown$vtable	_jc_soot_coffi_Instruction__5fUnknown$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fUnknown$vtype	_jc_soot_coffi_Instruction__5fUnknown$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fUnknown$method$_init$3f3083d4dc5dd7b4(_jc_env *, struct _jc_soot_coffi_Instruction__5fUnknown$object *, jbyte) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fUnknown$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fUnknown$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fUnknown$vmethods	soot_coffi_Instruction__5fUnknown;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fUnknown$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fUnknown$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fUnknown$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fUnknown$refs {
    _jc_soot_coffi_Instruction__5fUnknown$sub_refs	soot_coffi_Instruction__5fUnknown;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fUnknown$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fUnknown$sub_nonrefs	soot_coffi_Instruction__5fUnknown;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fUnknown$object {
	_jc_soot_coffi_Instruction__5fUnknown$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fUnknown$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fUnknown$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fUnknown$vtype _jc_soot_coffi_Instruction__5fUnknown$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fUnknown, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fUnknown$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fUnknown_H_ */
